@@ -50,7 +50,15 @@ set_live_bg (Display *display, Window xwindow, int mode)
                   (unsigned char *) &mode, 1);
 }
 /*******************************************************************************/
+gboolean
+delayed_pause_video (AWallpaperPlugin *desktop_plugin){
 
+    if (!desktop_plugin->priv->visible){
+        gst_element_set_state (desktop_plugin->priv->pipeline, GST_STATE_PAUSED);
+    }
+    return FALSE;
+}
+/*******************************************************************************/
 void
 view_state_changed (Animation_WallpaperPrivate *priv)
 {
@@ -72,7 +80,7 @@ view_state_changed (Animation_WallpaperPrivate *priv)
        }
 
        if (!priv->running){
-            if (g_hash_table_lookup(priv->hash_theme, "exec_path")){
+            if (priv->hash_theme && g_hash_table_lookup(priv->hash_theme, "exec_path")){
                 init_scene_External(priv->desktop_plugin);
             }
        }
@@ -85,7 +93,10 @@ view_state_changed (Animation_WallpaperPrivate *priv)
    }else{
         /* For Video */
         if (priv->pipeline){
-           gst_element_set_state (priv->pipeline, GST_STATE_PAUSED);
+           if (priv->one_in_all_view)
+                g_timeout_add(200, (GtkFunction)delayed_pause_video, priv->desktop_plugin);
+           else
+                gst_element_set_state (priv->pipeline, GST_STATE_PAUSED);
            return;
         }
         /* For Conky */
@@ -253,7 +264,7 @@ long_timeout (AWallpaperPlugin *desktop_plugin)
 
     /*fprintf(stderr, "long_timeout %i\n", desktop_plugin->priv->long_timer); */
     if (desktop_plugin->priv->pipeline){
-	if (!desktop_plugin->priv->visible){
+	if (!desktop_plugin->priv->visible && !desktop_plugin->priv->theme_bool_parametr1){
 		gst_element_query_position(desktop_plugin->priv->pipeline, &fmt, &p);
 		desktop_plugin->priv->theme_int_parametr1 = p / GST_SECOND;
 		gst_element_set_state (desktop_plugin->priv->pipeline, GST_STATE_NULL);
