@@ -566,7 +566,7 @@ cb_timeout_settings(GtkWidget *window){
 
     if (window)
         gtk_widget_destroy(window);
-    return TRUE;
+    return FALSE;
 }
 /*******************************************************************************/
 void
@@ -603,6 +603,7 @@ void
 additional_parametr_for_theme_video(GtkWidget *vbox, Animation_WallpaperPrivate *priv){
 
     GtkWidget *file_button;
+    GtkWidget *smoothing_button;
     GtkWidget *rich_animation_button;
 
     if (priv->theme_string_parametr1)
@@ -622,16 +623,13 @@ additional_parametr_for_theme_video(GtkWidget *vbox, Animation_WallpaperPrivate
     gtk_box_pack_start(GTK_BOX(vbox),
                                    rich_animation_button, TRUE, TRUE, 5);
     g_object_set_data(G_OBJECT(priv->window), "rich_animation_button", rich_animation_button);
-    /* Create sound button */  
-#if 0
+    /* Create Smoothing button */  
 
-    /* Doesn't work in real device. Hardware volume buttons can to change volume for mutted track */
-    sound_button = create_bool_button(priv->theme_bool_parametr1, _("Sound"));
+    smoothing_button = create_bool_button(priv->theme_bool_parametr1, _("Smoothing (Need more memory)"));
     gtk_box_pack_start(GTK_BOX(vbox),
-                                   sound_button, TRUE, TRUE, 5);
-    g_object_set_data(G_OBJECT(priv->window), "sound_button", sound_button);
-    gtk_widget_show (sound_button);
-#endif
+                                   smoothing_button, TRUE, TRUE, 5);
+    g_object_set_data(G_OBJECT(priv->window), "smoothing_button", smoothing_button);
+    gtk_widget_show (smoothing_button);
     gtk_widget_show (file_button);
     gtk_widget_show (rich_animation_button);
 
@@ -656,6 +654,7 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
     GtkWidget *enable_button;
     GtkWidget *vbox;
     GtkWidget *area_vbox;
+    GtkWidget *temp_button; 
     GtkWidget *button1 = NULL;
     GtkWidget *rich_animation_button = NULL;
     gint view = priv->view;
@@ -788,15 +787,13 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
                             g_free(priv->theme_string_parametr1);
                         priv->theme_string_parametr1 = g_strdup((gchar*)hildon_button_get_value (HILDON_BUTTON(button1)));
                     }
-                    /* 
-                    temp_button = g_object_get_data(G_OBJECT(priv->window), "sound_button");
+                    temp_button = g_object_get_data(G_OBJECT(priv->window), "smoothing_button");
                     if (temp_button){
                         if (hildon_check_button_get_active (HILDON_CHECK_BUTTON(temp_button)))
                             priv->theme_bool_parametr1 = TRUE;
                         else
                             priv->theme_bool_parametr1 = FALSE;
                     }
-                    */
                 }
                 /* Check external themes */
                 GSList *store = priv->extheme_list;
